import React, { useState, useEffect, useMemo, useRef } from "react";
import DrawerPro from "@/components/DrawerPro";
import AutoTable from "@/components/AutoTable";
import PremButton from "@/components/PremButton";
import useKeepAlive from "@/components/useKeepAlive";
import getcolumns from "./columns";
import { useRequest } from "ahooks";
import { doFetch } from "@/utils/doFetch";
import { message } from "antd";
function Traymanage() {
  let actionRef = useRef();
  const [drawer, setdrawer] = useState({
    open: false,
  });
  const { runAsync } = useRequest(doFetch, {
    manual: true,
    onSuccess: (res, params) => {
      if (res?.code == "0000") {
        reload();
      }
    },
  });
  const columns = useMemo(() => {
    let defcolumn = getcolumns(drawer?.val);
    return defcolumn.concat({
      title: "操作",
      valueType: "option",
      width: 80,
      render: (text, row, _, action) => rightExtra(text, row, _, action),
    });
  }, []);
  const fields = useMemo(() => {
    let defcolumn = getcolumns(drawer?.val);
    return defcolumn;
  }, [drawer?.val]);
  const rightExtra = (text, row, _, action) => {
    return [
      <PremButton
        key="edit"
        btn={{
          type: "primary",
          size: "small",
          onClick: () => {
            setdrawer((s) => {
              return {
                ...s,
                open: true,
                title: "修改托盘",
                val: "edit",
                item: row,
              };
            });
          },
        }}
      >
        修改
      </PremButton>,
      row?.storeCode == 60 && (
        <PremButton
          key="jb"
          pop={{
            title: "是否解绑该空托盘?",
            okText: "确认",
            cancelText: "取消",
            onConfirm: async () => {
              await runAsync({
                url: "/ta_wms_auth/sysTray/unbind",
                params: { id: row.id },
              });
            },
          }}
          btn={{
            size: "small",
          }}
        >
          解绑
        </PremButton>
      ),

      <PremButton
        key="delete"
        pop={{
          title: "是否删除该托盘?",
          okText: "确认",
          cancelText: "取消",
          onConfirm: async () => {
            await runAsync({
              url: "/ta_wms_auth/sysTray/deleteById",
              params: { id: row.id },
            });
          },
        }}
        btn={{
          size: "small",
          danger: true,
        }}
      >
        删除
      </PremButton>,
    ];
  };
  function reload() {
    actionRef?.current?.reload();
    setdrawer((s) => ({
      ...s,
      open: false,
    }));
  }
  return (
    <div>
      <AutoTable
        pagetitle="托盘管理"
        columns={columns}
        path="/ta_wms_auth/sysTray/queryPage"
        actionRef={actionRef}
        pageextra="add"
        addconfig={{
          // access: 'sysDepartment_save',
          name: "新增",
          btn: {
            type: "primary",
            onClick: () => {
              setdrawer((s) => ({
                ...s,
                open: true,
                title: "新增",
                val: "add",
                item: {},
              }));
            },
          },
        }}
      />
      <DrawerPro
        {...drawer}
        fields={fields}
        defaultFormValue={drawer?.item}
        placement="right"
        onClose={() => {
          setdrawer((s) => ({
            ...s,
            open: false,
          }));
        }}
        onFinish={async (vals) => {
          let newfields = JSON.parse(JSON.stringify(vals));
          await runAsync({
            url: "/ta_wms_auth/sysTray/save",
            params: {
              ...newfields,
              id: drawer?.val === "edit" ? drawer?.item?.id : "",
            },
          });
        }}
        width="60%"
      />
    </div>
  );
}

export default useKeepAlive(Traymanage);
